@@ -26,6 +26,29 @@ class PrivatednsClient(AbstractClient):
     _service = 'privatedns'
 
 
+    def AddSpecifyPrivateZoneVpc(self, request):
+        """追加与私有域关联的VPC
+
+        :param request: Request instance for AddSpecifyPrivateZoneVpc.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.AddSpecifyPrivateZoneVpcRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.AddSpecifyPrivateZoneVpcResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AddSpecifyPrivateZoneVpc", params, headers=headers)
+            response = json.loads(body)
+            model = models.AddSpecifyPrivateZoneVpcResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreatePrivateDNSAccount(self, request):
         """创建私有域解析账号
 
@@ -187,6 +210,29 @@ class PrivatednsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteSpecifyPrivateZoneVpc(self, request):
+        """删除与私有域关联的VPC
+
+        :param request: Request instance for DeleteSpecifyPrivateZoneVpc.
+        :type request: :class:`tencentcloud.privatedns.v20201028.models.DeleteSpecifyPrivateZoneVpcRequest`
+        :rtype: :class:`tencentcloud.privatedns.v20201028.models.DeleteSpecifyPrivateZoneVpcResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteSpecifyPrivateZoneVpc", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteSpecifyPrivateZoneVpcResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAccountVpcList(self, request):
         """获取私有域解析账号的VPC列表
 
